severity 594541 grave
thanks

Raising severity, as kolabmailboxfilter is half of php-kolab-filter package.

On Fri, Sep 10, 2010 at 12:44 AM, Mathieu Parent <math.par...@gmail.com> wrote:
...
> As a first step can you add the following to the top of the
> /usr/bin/kolabmailboxfilter script:
>
> ini_set("display_errors", 0);
>
> (of course, after the <?php, but you know that). The default value in
> Debian is Off so postfix should not see those warnings.


My previous fix is false because the printed message comes from an
error handler.

Attached patch is a better one that:
* remove all mentioned "Assigning the return value of new by
reference is deprecated"
* Ignore any E_DEPRECATED error within Kolab_Freebusy

Can you please test?

In the meantime, as I have teted myself, I will upload the fix and ask
freeze-exception.

Mathieu Parent
diff -ur usr/share/php/Horde//Kolab/Filter/Incoming.php /usr/share/php/Horde//Kolab/Filter/Incoming.php
--- usr/share/php/Horde//Kolab/Filter/Incoming.php	2010-07-05 22:35:21.000000000 +0000
+++ /usr/share/php/Horde//Kolab/Filter/Incoming.php	2010-09-10 06:38:52.000000000 +0000
@@ -143,7 +143,7 @@
                                           $this->_fqhostname, $this->_sender,
                                           $resource, $this->_tmpfile), __FILE__, __LINE__,
                                   PEAR_LOG_DEBUG);
-                $r = &new Kolab_Resource();
+                $r = new Kolab_Resource();
                 $rc = $r->handleMessage($this->_fqhostname, $this->_sender,
                                         $resource, $this->_tmpfile);
                 $r->cleanup();
diff -ur usr/share/php/Horde//Kolab/Filter/Transport.php /usr/share/php/Horde//Kolab/Filter/Transport.php
--- usr/share/php/Horde//Kolab/Filter/Transport.php	2010-07-05 22:35:21.000000000 +0000
+++ /usr/share/php/Horde//Kolab/Filter/Transport.php	2010-09-10 06:39:32.000000000 +0000
@@ -75,7 +75,7 @@
             include dirname(__FILE__) . '/Transport/' . $driver . '.php';
         }
         if (class_exists($class)) {
-            $transport = &new $class($params);
+            $transport = new $class($params);
             return $transport;
         }
         return PEAR::raiseError(sprintf('No such class \"%s\"', $class),
--- usr/bin/kolabmailboxfilter	2010-09-10 06:27:49.000000000 +0000
+++ /usr/bin/kolabmailboxfilter	2010-09-10 06:38:40.000000000 +0000
@@ -19,8 +19,8 @@
 require_once 'Horde/Kolab/Filter/Response.php';
 
 /* Parse the mail */
-$parser = &new Horde_Kolab_Filter_Incoming();
-$response = &new Horde_Kolab_Filter_Response();
+$parser = new Horde_Kolab_Filter_Incoming();
+$response = new Horde_Kolab_Filter_Response();
 
 $result = $parser->parse();
 if (is_a($result, 'PEAR_Error')) {

Reply via email to
diff -ur usr/share/php/Horde//Kolab/Filter/Response.php /usr/share/php/Horde//Kolab/Filter/Response.php
--- usr/share/php/Horde//Kolab/Filter/Response.php	2010-07-05 22:35:21.000000000 +0000
+++ /usr/share/php/Horde//Kolab/Filter/Response.php	2010-09-10 07:08:55.000000000 +0000
@@ -103,10 +103,10 @@
      */
     function _fatal($errno, $errmsg, $filename, $linenum, $vars)
     {
         /* Ignore strict errors for now since even PEAR will raise
          * strict notices 
          */
-        if ($errno == E_STRICT) {
+        if (($errno == E_STRICT) || ($errno == E_DEPRECATED)) {
             return false;
         }
 
@@ -124,7 +124,7 @@
             $msg = 'PHP Error: ' . $errmsg;
         }
 
-        $error = &new PEAR_Error($msg, $code);
+        $error = new PEAR_Error($msg, $code);
         $this->handle($error);
 
         return false;
@@ -103,10 +103,10 @@
     function _fatal($errno, $errmsg, $filename, $linenum, $vars)
     {
-        /* Ignore strict errors for now since even PEAR will raise
-         * strict notices 
+        /* Ignore strict and deprecated errors for now since even
+         * PEAR will raise strict and deprecated notices 
          */